#
# spec file for package univocity-parsers
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           univocity-parsers
Version:        2.9.1
Release:        1.9
Summary:        Collection of parsers for Java
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/uniVocity/univocity-parsers
Source0:        https://github.com/uniVocity/univocity-parsers/archive/v%{version}.tar.gz
Source1:        %{name}-build.xml
Patch0:         0001-Resolve-import-clash-with-OpenJDK-17.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildArch:      noarch

%description
uniVocity-parsers is a suite of parsers for Java. It provides an
interface for handling different file formats, and a framework for
the development of new parsers.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml
%patch0 -p1

# Tests require univocity-output-tester, which is not packaged yet.
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE-2.0.html

%files javadoc
%license LICENSE-2.0.html
%{_javadocdir}/%{name}

%changelog
* Mon May  9 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 2.9.1
  * Bugs fixed
    + Quote escape configured to double quote (quote value)
    character if escape not detected
    + Delimiter detection returns first candidate delimiter even if
    it does not exist in the file
    + context.getSelectedHeaders() in RowProcessor processStarted()
    can return invalid results
    + DefaultNullRead of @parsed does not work with enums
    + Missing fields not initialized if nested beans present
    + Possible race condition
    + Implicit limitation on max column name length?
    + CSV auto-detection assigning line ending as quote escape
    + FixedWidthFields.keepPadding not working
    + Multi-char delimiter incorrectly detected inside quoted string
    + Fixed the repeatable conversions initialization in the
    DefaultConversionProcessor
    + Fix NPE in EnumConversion
    + Fixed quoted parser when using non-printable char as delimiter
  * Enhancements
    + Delimiter detection returns first candidate delimiter even if
    it does not exist in the file
    + Custom CsvFormatDetector
    + Detects "whitespace" as delimiter instead of "comma"
    + make the maxRowSample for parameter public configurable for
    CSV auto-detection
    + settings.excludeFields() doesn't throw errors for
    non-existing fields anymore.
    + Expose InputAnalysisProcess implementations publicly
    + add "com.googlecode.openbeans" as an optional OSGi dependency
- Removed patch:
  * ambiguous-Record.patch
    + Not sufficient with this version
  * 0001-Resolve-import-clash-with-OpenJDK-17.patch
    + fix name clash with the new java.lang.Record
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * ambiguous-Record.patch
    + fix name clash with the new java.lang.Record
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Fri Mar 15 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of univocity-parsers 2.5.5
- Generate and customize ant build.xml file
